searchData={"items":[{"type":"module","title":"OtelMetricExporter","doc":"This is a `telemetry` exporter that collects specified metrics\nand then exports them to an OTel endpoint. It uses metric definitions\nfrom `:telemetry_metrics` library.\n\nExample usage:\n\n    OtelMetricExporter.start_link(\n      otlp_protocol: :http_protobuf,\n      otlp_endpoint: otlp_endpoint,\n      otlp_headers: headers,\n      otlp_compression: :gzip,\n      export_period: :timer.seconds(30),\n      metrics: [\n        Telemetry.Metrics.counter(\"plug.request.stop.duration\"),\n        Telemetry.Metrics.sum(\"plug.request.stop.duration\"),\n        Telemetry.Metrics.last_value(\"plug.request.stop.duration\"),\n        Telemetry.Metrics.distribution(\"plug.request.stop.duration\",\n          reporter_options: [buckets: [0, 10, 100, 1000]] # Optional histogram buckets.\n        ),\n      ]\n    )\n\nDefault histogram buckets are `[0, 5, 10, 25, 50, 75, 100, 250, 500, 750, 1000, 2500, 5000, 7500, 10000]`\n\nSee all available options in `start_link/2` documentation. Options provided to the `start_link/2`\nfunction will be merged with the options provided via `config :otel_metric_exporter` configuraiton.","ref":"OtelMetricExporter.html"},{"type":"function","title":"OtelMetricExporter.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"OtelMetricExporter.html#child_spec/1"},{"type":"type","title":"OtelMetricExporter.compression/0","doc":"","ref":"OtelMetricExporter.html#t:compression/0"},{"type":"type","title":"OtelMetricExporter.option/0","doc":"","ref":"OtelMetricExporter.html#t:option/0"},{"type":"type","title":"OtelMetricExporter.protocol/0","doc":"","ref":"OtelMetricExporter.html#t:protocol/0"},{"type":"function","title":"OtelMetricExporter.start_link/1","doc":"Start the exporter. It maintains some pieces of global state: ets table and a `:persistent_term` key.\nThis means that only one exporter instance can be started at a time.","ref":"OtelMetricExporter.html#start_link/1"},{"type":"function","title":"Options - OtelMetricExporter.start_link/1","doc":"Options can be provided directly or specified in the `config :otel_metric_exporter` configuration. It's recommended\nto configure global options in `:otel_metric_exporter` config, and specify metrics where you add this module to the\nsupervision tree.\n\n* `:metrics` - Required. List of telemetry metrics to track.\n\n* `:export_period` (`t:pos_integer/0`) - Period in milliseconds between metric exports. The default value is `60000`.\n\n* `:name` (`t:atom/0`) - If you require multiple exporters, give each exporter a unique name. The default value is `:otel_metric_exporter`.\n\n* `:otlp_endpoint` (`t:String.t/0`) - Required. Endpoint to send data to.\n\n* `:otlp_protocol` - Protocol to use for OTLP export. Currently only `:http_protobuf` is supported. The default value is `:http_protobuf`.\n\n* `:otlp_headers` (map of `t:String.t/0` keys and `t:String.t/0` values) - Headers to send with OTLP requests. The default value is `%{}`.\n\n* `:otlp_compression` - Compression to use for OTLP requests. Allowed values are `:gzip` and `nil`. The default value is `:gzip`.\n\n* `:otlp_concurrent_requests` (`t:non_neg_integer/0`) - Number of concurrent requests to send to the OTLP endpoint. The default value is `10`.\n\n* `:resource` (`t:map/0`) - Resource attributes to send with collected data. The default value is `%{}`.","ref":"OtelMetricExporter.html#start_link/1-options"},{"type":"module","title":"OtelMetricExporter.Application","doc":"","ref":"OtelMetricExporter.Application.html"},{"type":"module","title":"OtelMetricExporter.LogHandler","doc":"A Logger handler that forwards log events to OTel collector via OTLP protocol.\n\nThis can be installed as a handler for the `:logger` application.\n\nExample:\n\n    # Add and configure the handler\n    config :my_app, :logger, [\n      {:handler, OtelMetricExporter.LogHandler, :logger_std_h, %{\n        config: %{\n          metadata_map: %{\n            request_id: \"http.request.id\"\n          }\n        },\n      }}\n    ]\n\n    # Configure the resource and endpoint\n    config :otel_metric_exporter,\n      otlp_protocol: :http_protobuf,\n      otlp_endpoint: otlp_endpoint,\n      resource: %{\n        name: \"metrics\",\n        service: %{name: service_name, version: version},\n        instance: %{id: instance_id}\n      }\n\nIt should then be explicitly attached by executing `Logger.add_handlers(:my_app)` in `Application.start/2` callback\nof your application.","ref":"OtelMetricExporter.LogHandler.html"},{"type":"module","title":"Options - OtelMetricExporter.LogHandler","doc":"Options starting with `otlp_` and the `resource` option will be take automatically from the `:otel_metric_exporter`\napp configuration, but can be overridden when adding the handler.\n\n* `:metadata` (list of `t:atom/0`) - A list of atoms from metadata to attach as attribute to the log event The default value is `[]`.\n\n* `:metadata_map` (map of `t:atom/0` keys and `t:String.t/0` values) - Remapping of metadata keys to different attribute names.\n  Example: Plug adds a `request_id` metadata key to log events, but\n  semantic convention for OTel is to use `http.request.id`. This can be\n  achieved by specifying this field to `%{request_id: \"http.request.id\"}` The default value is `%{}`.\n\n* `:debounce_ms` (`t:non_neg_integer/0`) - Period to accumulate logs before sending them The default value is `5000`.\n\n* `:max_buffer_size` (`t:non_neg_integer/0`) - Max amount of log events to store before sending them The default value is `10000`.\n\n* `:otlp_endpoint` (`t:String.t/0`) - Required. Endpoint to send data to.\n\n* `:otlp_protocol` - Protocol to use for OTLP export. Currently only `:http_protobuf` is supported. The default value is `:http_protobuf`.\n\n* `:otlp_headers` (map of `t:String.t/0` keys and `t:String.t/0` values) - Headers to send with OTLP requests. The default value is `%{}`.\n\n* `:otlp_compression` - Compression to use for OTLP requests. Allowed values are `:gzip` and `nil`. The default value is `:gzip`.\n\n* `:otlp_concurrent_requests` (`t:non_neg_integer/0`) - Number of concurrent requests to send to the OTLP endpoint. The default value is `10`.\n\n* `:resource` (`t:map/0`) - Resource attributes to send with collected data. The default value is `%{}`.","ref":"OtelMetricExporter.LogHandler.html#module-options"},{"type":"module","title":"OtelMetricExporter.TelemetryHandlers","doc":"","ref":"OtelMetricExporter.TelemetryHandlers.html"},{"type":"function","title":"OtelMetricExporter.TelemetryHandlers.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"OtelMetricExporter.TelemetryHandlers.html#child_spec/1"},{"type":"function","title":"OtelMetricExporter.TelemetryHandlers.name/1","doc":"","ref":"OtelMetricExporter.TelemetryHandlers.html#name/1"},{"type":"function","title":"OtelMetricExporter.TelemetryHandlers.setup_telemetry_handlers/1","doc":"","ref":"OtelMetricExporter.TelemetryHandlers.html#setup_telemetry_handlers/1"},{"type":"function","title":"OtelMetricExporter.TelemetryHandlers.start_link/1","doc":"","ref":"OtelMetricExporter.TelemetryHandlers.html#start_link/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.0"}}